@@ -232,7 +232,7 @@ summary.ivreg <- function(object, vcov. = NULL, df = NULL, ...)
   ## Wald test of all coefficients
   Rmat <- if(attr(object$terms$regressors, "intercept"))
     cbind(0, diag(length(coef(object))-1)) else diag(length(coef(object)))
-  waldtest <- linear.hypothesis(object, Rmat, vcov. = vcov., test = ifelse(df > 0, "F", "Chisq"))
+  waldtest <- linearHypothesis(object, Rmat, vcov. = vcov., test = ifelse(df > 0, "F", "Chisq"))
   waldtest <- c(waldtest[2,3], waldtest[2,4], -waldtest[2,2], if(df > 0) waldtest[1,1] else NULL)
   
   rval <- list(
